@@ -1,10 +1,6 @@
-from pip._internal.utils.typing import MYPY_CHECK_RUNNING
+from typing import List, Optional
 
-if MYPY_CHECK_RUNNING:
-    from typing import List, Optional
-
-
-__version__ = "20.3.3"
+__version__ = "21.1.1"
 
 
 def main(args=None):
